==> jbossws-spi-2.2.0.CR1-sources.jar: org/jboss/wsf/spi/metadata/jms/JMSEndpointsMetaData.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2010, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.spi.metadata.jms;

import java.util.LinkedList;
import java.util.List;

/**
 * @author <a href="ema@redhat.com">Jim Ma</a>
 */
public final class JMSEndpointsMetaData
{

   private List<JMSEndpointMetaData> jmsEndpointsMD = new LinkedList<JMSEndpointMetaData>();

   public void addEndpointMetaData(JMSEndpointMetaData endpointMetaData)
   {
       jmsEndpointsMD.add(endpointMetaData);
   }
   
   public List<JMSEndpointMetaData> getEndpointsMetaData() {
      return jmsEndpointsMD;
   }

}

==> jbossws-spi-3.0.0.CR1-sources.jar: org/jboss/wsf/spi/metadata/jms/JMSEndpointsMetaData.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2013, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.wsf.spi.metadata.jms;

import java.util.Collections;
import java.util.List;

/**
 * @author <a href="ema@redhat.com">Jim Ma</a>
 * @author <a href="alessio.soldano@jboss.com">Alessio Soldano</a>
 */
public final class JMSEndpointsMetaData
{
   private final List<JMSEndpointMetaData> jmsEndpointsMD;
   
   public JMSEndpointsMetaData(List<JMSEndpointMetaData> jmsEndpointsMD)
   {
      if (jmsEndpointsMD != null && !jmsEndpointsMD.isEmpty()) {
         this.jmsEndpointsMD = Collections.unmodifiableList(jmsEndpointsMD);
      } else {
         this.jmsEndpointsMD = Collections.emptyList();
      }
   }

   public List<JMSEndpointMetaData> getEndpointsMetaData() {
      return jmsEndpointsMD;
   }

}
